@@ -10,7 +10,7 @@ from django.core.mail import EmailMessage as DjangoEmailMessage
 
 
 class Notification(models.Model):
-    Pending = 0
+    READY = 0
     SUCCESS = 1
     FAILED = 2
 
